use salvo::{handler, hyper::header::HOST, prelude::StatusCode, Request, Response};
use std::path::PathBuf;

use crate::handlers::{render_template, TemplateStruct};

/// This file handles (heh) the main index page for the application.
#[handler]
pub async fn index(req: &mut Request, res: &mut Response) {
    // Get the headers (for Host header stuff thats needed later)
    let headers = req.headers();
    let host = headers[HOST].to_str().unwrap_or("localhost:8282");
    tracing::info!("New Request: /");

    // Renders the template based on `/templates/$host/upload.html`
    let template_host_path = PathBuf::from("./templates/").join(host);
    tracing::debug!("template_with_host: {:?}", template_host_path);

    let template = TemplateStruct {
        domain: String::from(headers[HOST].to_str().unwrap()),
        message1: String::from("Error 401: Unauthorised"),
        message2: String::from(
            "You have entered an invalid adminkey, please enter a valid adminkey",
        ),
        ..Default::default()
    };
    render_template(res, headers, "upload.html", template, StatusCode::OK).await
}
